@@ -1,13 +1,9 @@
-// #![feature(type_alias_impl_trait)]
-// #![feature(box_syntax)]
 #![forbid(missing_debug_implementations)]
 #![forbid(rustdoc::missing_crate_level_docs)]
 #![doc = include_str!("../Readme.md")]
 #![doc(html_logo_url = "https://upload.wikimedia.org/wikipedia/commons/d/d5/Tailwind_CSS_Logo.svg")]
 #![doc(html_favicon_url = "https://upload.wikimedia.org/wikipedia/commons/d/d5/Tailwind_CSS_Logo.svg")]
 
-extern crate core;
-
 mod macros;
 mod modules;
 mod systems;
