@@ -5,7 +5,7 @@ macro_rules! keyword_instance {
             T: Into<String>,
         {
             fn from(input: T) -> Self {
-                Self { kind: KeywordOnly::from(input) }
+                Self { kind: StandardValue::from(input.into()) }
             }
         }
         impl TailwindInstance for $t {
@@ -20,9 +20,12 @@ macro_rules! keyword_instance {
 
 macro_rules! color_instance {
     ($t:ty) => {
-        impl From<TailwindColor> for $t {
-            fn from(color: TailwindColor) -> Self {
-                Self { color }
+        impl<T> From<T> for $t
+        where
+            T: Into<TailwindColor>,
+        {
+            fn from(color: T) -> Self {
+                Self { color: color.into() }
             }
         }
         impl $t {
@@ -38,9 +41,16 @@ macro_rules! color_instance {
     };
 }
 macro_rules! css_insert {
-    ($css:expr, "transform", $v:expr) => {
-        $css.transform($v.to_string());
-    };
+    // not work!!!
+    // ($css:expr, "transform", $v:expr) => {
+    //     $css.transform($v.to_string());
+    // };
+    // ($css:expr, "filter", $v:expr) => {
+    //     $css.filter($v.to_string());
+    // };
+    // ($css:expr, "backdrop-filter", $v:expr) => {
+    //     $css.backdrop_filter($v.to_string());
+    // };
     ($css:expr, $k:expr,  $v:expr) => {
         $css.insert($k.to_string(), $v.to_string());
     };
