@@ -1,5 +1,3 @@
 mod screen_reader;
-#[cfg(test)]
-mod test;
 
 pub use screen_reader::TailwindScreenReader;
