@@ -22,6 +22,6 @@ impl TailwindInstance for TailwindBackgroundPosition {
 
 impl TailwindBackgroundPosition {
     pub fn parse(pattern: &[&str], arbitrary: &TailwindArbitrary) -> Result<Self> {
-        Ok(Self { kind: AnchorPoint::parse(pattern, arbitrary)? })
+        Ok(Self { kind: AnchorPoint::parse(pattern, arbitrary, true)? })
     }
 }
