@@ -6,11 +6,7 @@ pub struct TailwindBorderColor {
     color: TailwindColor,
 }
 
-impl From<TailwindColor> for TailwindBorderColor {
-    fn from(color: TailwindColor) -> Self {
-        Self { color }
-    }
-}
+crate::macros::sealed::color_instance!(TailwindBorderColor);
 
 impl Display for TailwindBorderColor {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
@@ -19,7 +15,7 @@ impl Display for TailwindBorderColor {
 }
 
 impl TailwindInstance for TailwindBorderColor {
-    fn attributes(&self, ctx: &TailwindBuilder) -> BTreeSet<CssAttribute> {
+    fn attributes(&self, ctx: &TailwindBuilder) -> CssAttributes {
         css_attributes! {
             "border-color" => self.color.get_properties(ctx)
         }
