@@ -1,9 +1,9 @@
 use super::*;
 
-#[doc = include_str!("readme.md")]
+#[doc=include_str!("readme.md")]
 #[derive(Clone, Debug)]
 pub struct TailwindSaturate {
-    percent: IntegerOnly,
+    percent: NumericValue,
     backdrop: Backdrop,
 }
 
@@ -16,25 +16,18 @@ impl Display for TailwindSaturate {
 
 impl TailwindInstance for TailwindSaturate {
     fn attributes(&self, _: &TailwindBuilder) -> CssAttributes {
-        let class = self.backdrop.filter();
-        let value = match &self.percent {
-            IntegerOnly::Number(n) => format!("saturate({}%)", n),
-            IntegerOnly::Arbitrary(n) => format!("saturate({})", n),
-        };
-        css_attributes! {
-            class => value
-        }
+        let n = self.percent.get_properties(|f| format!("{}%", f));
+        self.backdrop.get_filter(format!("saturate({})", n))
     }
 }
 
 impl TailwindSaturate {
     /// <https://tailwindcss.com/docs/saturate>
     pub fn parse(rest: &[&str], arbitrary: &TailwindArbitrary, backdrop: bool) -> Result<Self> {
-        let percent = IntegerOnly::parser("saturate")(rest, arbitrary)?;
-        Ok(Self { percent, backdrop: Backdrop::from(backdrop) })
-    }
-    pub fn parse_arbitrary(arbitrary: &TailwindArbitrary, backdrop: bool) -> Result<Self> {
-        let percent = IntegerOnly::parse_arbitrary(arbitrary)?;
+        let percent = match rest {
+            [] if arbitrary.is_none() => 100u32.into(),
+            _ => NumericValue::positive_parser("saturate", |_| false)(rest, arbitrary)?,
+        };
         Ok(Self { percent, backdrop: Backdrop::from(backdrop) })
     }
 }
