@@ -1,14 +1,13 @@
 use super::*;
 
-#[doc = include_str!("readme.md")]
+#[doc=include_str!("readme.md")]
 #[derive(Clone, Debug)]
 pub struct TailwindSepia {
-    percent: IntegerOnly,
+    percent: NumericValue,
     backdrop: Backdrop,
 }
 impl Display for TailwindSepia {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
-        debug_assert!(self.percent <= 100);
         self.backdrop.write(f)?;
         write!(f, "sepia-{}", self.percent)
     }
@@ -16,23 +15,17 @@ impl Display for TailwindSepia {
 
 impl TailwindInstance for TailwindSepia {
     fn attributes(&self, _: &TailwindBuilder) -> CssAttributes {
-        let class = self.backdrop.filter();
-        let value = match &self.percent {
-            IntegerOnly::Number(n) => format!("sepia({}%)", n),
-            IntegerOnly::Arbitrary(n) => format!("sepia({})", n),
-        };
-        css_attributes! {
-            class => value
-        }
+        let n = self.percent.get_properties(|f| format!("{}%", f));
+        self.backdrop.get_filter(format!("sepia({})", n))
     }
 }
 
 impl TailwindSepia {
-    ///
+    /// <https://tailwindcss.com/docs/sepia>
     pub fn parse(rest: &[&str], arbitrary: &TailwindArbitrary, backdrop: bool) -> Result<Self> {
         let percent = match rest {
-            [] if arbitrary.is_none() => 100usize.into(),
-            _ => IntegerOnly::parser("sepia")(rest, arbitrary)?,
+            [] if arbitrary.is_none() => 100i32.into(),
+            _ => NumericValue::positive_parser("sepia", |_| false)(rest, arbitrary)?,
         };
         Ok(Self { percent, backdrop: Backdrop::from(backdrop) })
     }
