@@ -5,12 +5,13 @@ values = "
 grid-auto-flow: row;
 grid-auto-flow: column;
 grid-auto-flow: dense;
-grid-auto-flow: row-dense;
-grid-auto-flow: column-dense;
+grid-auto-flow: row dense;
+grid-auto-flow: column dense;
 
 /* Global values */
 grid-auto-flow: inherit;
 grid-auto-flow: initial;
+grid-auto-flow: revert;
 grid-auto-flow: unset;
 ";
 
@@ -18,4 +19,4 @@ all = Sort@StringCases[
     values,
     RegularExpression[":\\s*([a-zA-Z0-9-]+);"] :> "$1"
 ];
-"let set = BTreeSet::from_iter(vec![\"" <> StringRiffle[all, "\",\""] <> "\"]);" // CopyToClipboard
+"[\"" <> StringRiffle[all, "\",\""] <> "\"].contains(&mode)" // CopyToClipboard
