@@ -3,7 +3,7 @@ use super::*;
 #[doc=include_str!("readme.md")]
 #[derive(Debug, Clone)]
 pub struct TailwindJustifySelf {
-    kind: KeywordOnly,
+    kind: StandardValue,
 }
 
 crate::macros::sealed::keyword_instance!(TailwindJustifySelf => "justify-self");
@@ -17,11 +17,11 @@ impl Display for TailwindJustifySelf {
 impl TailwindJustifySelf {
     /// <https://tailwindcss.com/docs/justify-self>
     pub fn parse(pattern: &[&str], arbitrary: &TailwindArbitrary) -> Result<Self> {
-        Ok(Self { kind: KeywordOnly::parser("justify-self", &Self::check_valid)(pattern, arbitrary)? })
+        Ok(Self { kind: StandardValue::parser("justify-self", &Self::check_valid)(pattern, arbitrary)? })
     }
     /// dispatch to [justify-self](https://developer.mozilla.org/en-US/docs/Web/CSS/justify-self)
     pub fn parse_arbitrary(arbitrary: &TailwindArbitrary) -> Result<Self> {
-        Ok(Self { kind: KeywordOnly::parse_arbitrary(arbitrary)? })
+        StandardValue::parse_arbitrary(arbitrary).map(|kind| Self { kind })
     }
     /// <https://developer.mozilla.org/en-US/docs/Web/CSS/justify-self#syntax>
     pub fn check_valid(mode: &str) -> bool {
