@@ -2,7 +2,12 @@ use std::{
     collections::BTreeSet,
     fmt::{Display, Formatter},
 };
-use crate::Negative;
+
+use crate::{
+    css_attributes, CssAttributes, Negative, Result, StandardValue, TailwindArbitrary, TailwindBuilder, TailwindColor,
+    TailwindInstance, TailwindScrollMargin, TailwindScrollPadding,
+};
+
 pub use self::{
     accent::TailwindAccentColor,
     appearance::TailwindAppearance,
@@ -10,16 +15,13 @@ pub use self::{
     cursor::TailwindCursor,
     pointer::TailwindPointerEvents,
     resize::TailwindResize,
-    scroll::TailwindScroll,
+    scroll::scroll_behavior::TailwindScrollBehavior,
     select::TailwindSelect,
-    snap::{snap_align::TailwindSnapAlign, snap_stop::TailwindSnapStop, snap_type::TailwindSnapType, TailwindSnap},
+    snap::{snap_align::TailwindSnapAlign, snap_stop::TailwindSnapStop, snap_type::TailwindSnapType},
     torch::TailwindTorch,
     will_change::TailwindWillChange,
 };
-use crate::{
-    css_attributes, CssAttributes, KeywordOnly, Result, TailwindArbitrary, TailwindBuilder, TailwindColor, TailwindInstance,
-    TailwindScrollMargin, TailwindScrollPadding,
-};
+pub(crate) use self::{scroll::scroll_adaptor, snap::snap_adaptor};
 
 mod accent;
 mod appearance;
@@ -30,7 +32,5 @@ mod resize;
 mod scroll;
 mod select;
 mod snap;
-#[cfg(test)]
-mod test;
 mod torch;
 mod will_change;
