@@ -3,17 +3,10 @@ use super::*;
 #[doc=include_str!("readme.md")]
 #[derive(Debug, Clone)]
 pub struct TailwindPointerEvents {
-    kind: String,
+    kind: StandardValue,
 }
 
-impl<T> From<T> for TailwindPointerEvents
-where
-    T: Into<String>,
-{
-    fn from(kind: T) -> Self {
-        Self { kind: kind.into() }
-    }
-}
+crate::macros::sealed::keyword_instance!(TailwindPointerEvents => "pointer-events");
 
 impl Display for TailwindPointerEvents {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
@@ -21,23 +14,13 @@ impl Display for TailwindPointerEvents {
     }
 }
 
-impl TailwindInstance for TailwindPointerEvents {
-    fn attributes(&self, _: &TailwindBuilder) -> CssAttributes {
-        css_attributes! {
-            "pointer-events" => self.kind
-        }
-    }
-}
-
 impl TailwindPointerEvents {
-    /// https://tailwindcss.com/docs/pointer-events
+    /// <https://tailwindcss.com/docs/pointer-events>
     pub fn parse(pattern: &[&str], arbitrary: &TailwindArbitrary) -> Result<Self> {
-        debug_assert!(arbitrary.is_none(), "forbidden arbitrary after pointer-events");
-        let kind = pattern.join("-");
-        debug_assert!(Self::check_valid(&kind));
+        let kind = StandardValue::parser("pointer-events", &Self::check_valid)(pattern, arbitrary)?;
         Ok(Self { kind })
     }
-    /// https://developer.mozilla.org/en-US/docs/Web/CSS/pointer-events#syntax
+    /// <https://developer.mozilla.org/en-US/docs/Web/CSS/pointer-events#syntax>
     pub fn check_valid(mode: &str) -> bool {
         let set = BTreeSet::from_iter(vec![
             "all",
