@@ -3,17 +3,10 @@ use super::*;
 #[doc=include_str!("readme.md")]
 #[derive(Debug, Clone)]
 pub struct TailwindSelect {
-    kind: String,
+    kind: StandardValue,
 }
 
-impl<T> From<T> for TailwindSelect
-where
-    T: Into<String>,
-{
-    fn from(kind: T) -> Self {
-        Self { kind: kind.into() }
-    }
-}
+crate::macros::sealed::keyword_instance!(TailwindSelect => "user-select");
 
 impl Display for TailwindSelect {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
@@ -21,23 +14,13 @@ impl Display for TailwindSelect {
     }
 }
 
-impl TailwindInstance for TailwindSelect {
-    fn attributes(&self, _: &TailwindBuilder) -> CssAttributes {
-        css_attributes! {
-            "user-select" => self.kind
-        }
-    }
-}
-
 impl TailwindSelect {
-    /// https://tailwindcss.com/docs/user-select
+    /// <https://tailwindcss.com/docs/user-select>
     pub fn parse(pattern: &[&str], arbitrary: &TailwindArbitrary) -> Result<Self> {
-        debug_assert!(arbitrary.is_none(), "forbidden arbitrary after select");
-        let kind = pattern.join("-");
-        debug_assert!(Self::check_valid(&kind));
+        let kind = StandardValue::parser("select", &Self::check_valid)(pattern, arbitrary)?;
         Ok(Self { kind })
     }
-    /// https://developer.mozilla.org/en-US/docs/Web/CSS/user-select#syntax
+    /// <https://developer.mozilla.org/en-US/docs/Web/CSS/user-select#syntax>
     pub fn check_valid(mode: &str) -> bool {
         let set = BTreeSet::from_iter(vec!["all", "auto", "contain", "inherit", "initial", "none", "revert", "text", "unset"]);
         set.contains(mode)
