@@ -3,30 +3,32 @@ use super::*;
 #[doc=include_str!("readme.md")]
 #[derive(Clone, Debug)]
 pub struct TailwindRight {
-    negative: Negative,
-    kind: PlacementSize,
+    kind: UnitValue,
 }
 
 impl Display for TailwindRight {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
-        self.negative.write(f)?;
-        write!(f, "right-{}", self.kind)
+        self.kind.write_negative(f)?;
+        self.kind.write_class(f, "right-")
     }
 }
 
 impl TailwindInstance for TailwindRight {
     fn attributes(&self, _: &TailwindBuilder) -> CssAttributes {
         css_attributes! {
-            "right" => self.kind.get_properties()
+            "right" => self.kind.get_properties_rem()
         }
     }
 }
 
 impl TailwindRight {
+    /// <https://tailwindcss.com/docs/top-right-bottom-left>
     pub fn parse(pattern: &[&str], arbitrary: &TailwindArbitrary, negative: Negative) -> Result<Self> {
-        Ok(Self { negative, kind: PlacementSize::parse(pattern, arbitrary)? })
+        let kind = get_kind_px_full_auto_fact("right", pattern, arbitrary, negative)?;
+        Ok(Self { kind })
     }
-    pub fn parse_arbitrary(arbitrary: &TailwindArbitrary, negative: Negative) -> Result<Self> {
-        Ok(Self { negative, kind: PlacementSize::parse_arbitrary(arbitrary)? })
+    /// <https://developer.mozilla.org/en-US/docs/Web/CSS/right#syntax>
+    pub fn check_valid(mode: &str) -> bool {
+        check_valid_auto(mode)
     }
 }
