@@ -4,7 +4,7 @@ use super::*;
 pub(super) enum SpacingSize {
     Unit(f32),
     Standard(String),
-    Arbitrary(String),
+    Arbitrary(TailwindArbitrary),
 }
 
 impl Display for SpacingSize {
@@ -12,25 +12,24 @@ impl Display for SpacingSize {
         match self {
             Self::Unit(s) => write!(f, "{}", s),
             Self::Standard(s) => write!(f, "{}", s),
-            Self::Arbitrary(s) => write!(f, "[{}]", s),
+            Self::Arbitrary(s) => s.write(f),
         }
     }
 }
 
 impl SpacingSize {
-    pub fn parse(pattern: &[&str], arbitrary: &TailwindArbitrary) -> Result<Self> {
+    pub fn parse(pattern: &[&str], arbitrary: &TailwindArbitrary, check_valid: &'static impl Fn(&str) -> bool) -> Result<Self> {
         match pattern {
             [] => Self::parse_arbitrary(arbitrary),
-            ["px"] => Ok(Self::Arbitrary("1px".to_string())),
-            [n] if Self::check_valid(n) => Ok(Self::Standard(n.to_string())),
+            ["px"] => Ok(Self::Arbitrary(TailwindArbitrary::from("1px"))),
+            [n] if check_valid(n) => Ok(Self::Standard(n.to_string())),
             [n] => Ok(Self::Unit(TailwindArbitrary::from(*n).as_float()?)),
             _ => syntax_error!("Unknown padding instructions: {}", pattern.join("-")),
         }
     }
 
     pub fn parse_arbitrary(arbitrary: &TailwindArbitrary) -> Result<Self> {
-        debug_assert!(arbitrary.is_some());
-        Ok(Self::Arbitrary(arbitrary.to_string()))
+        Ok(Self::Arbitrary(TailwindArbitrary::new(arbitrary)?))
     }
 }
 impl SpacingSize {
@@ -38,12 +37,7 @@ impl SpacingSize {
         match self {
             Self::Unit(x) => format!("{}rem", x / 4.0),
             Self::Standard(x) => x.to_string(),
-            Self::Arbitrary(x) => x.to_string(),
+            Self::Arbitrary(x) => x.get_properties(),
         }
     }
-    /// https://developer.mozilla.org/en-US/docs/Web/CSS/padding#syntax
-    pub fn check_valid(mode: &str) -> bool {
-        let set = BTreeSet::from_iter(vec!["auto", "inherit", "initial", "revert", "unset"]);
-        set.contains(mode)
-    }
 }
