@@ -2,8 +2,8 @@ pub use self::{
     origin::TailwindOrigin, rotate::TailwindRotate, scale::TailwindScale, skew::TailwindSkew, translate::TailwindTranslate,
 };
 use crate::{
-    css_attributes, syntax_error, AnchorPoint, AxisXY, CssAttributes, IntegerOnly, LengthUnit, Negative, Result,
-    TailwindArbitrary, TailwindBuilder, TailwindInstance,
+    css_attributes, AnchorPoint, AxisXY, CssAttributes, Negative, NumericValue, Result, TailwindArbitrary, TailwindBuilder,
+    TailwindInstance, UnitValue,
 };
 use std::fmt::{Debug, Display, Formatter};
 
