@@ -22,4 +22,4 @@ all = Sort@StringCases[
     pointer,
     RegularExpression[":\\s*([a-zA-Z0-9-]+);"] :> "$1"
 ];
-"let set = BTreeSet::from_iter(vec![\"" <> StringRiffle[all, "\",\""] <> "\"]);" // CopyToClipboard
+"[\"" <> StringRiffle[all, "\",\""] <> "\"].contains(&mode)" // CopyToClipboard
