@@ -1,11 +1,11 @@
-use crate::KeywordOnly;
+use crate::StandardValue;
 
 use super::*;
 
 #[doc=include_str!("readme.md")]
 #[derive(Debug, Clone)]
 pub struct TailwindFontVariantNumeric {
-    kind: KeywordOnly,
+    kind: StandardValue,
 }
 
 crate::macros::sealed::keyword_instance!(TailwindFontVariantNumeric => "font-variant-numeric");
@@ -13,13 +13,13 @@ crate::macros::sealed::keyword_instance!(TailwindFontVariantNumeric => "font-var
 impl Display for TailwindFontVariantNumeric {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         match &self.kind {
-            KeywordOnly::Standard(s) => match s.as_str() {
+            StandardValue::Keyword(s) => match s.as_str() {
                 "normal" => write!(f, "normal-nums"),
                 "ordinal" | "slashed-zero" | "lining-nums" | "oldstyle-nums" | "proportional-nums" | "tabular-nums"
                 | "diagonal-fractions" | "stacked-fractions" => write!(f, "{}", s),
                 _ => write!(f, "font-numeric-{}", s),
             },
-            KeywordOnly::Arbitrary(s) => write!(f, "font-numeric-[{}]", s),
+            StandardValue::Arbitrary(s) => write!(f, "font-numeric-{}", s.get_class()),
         }
     }
 }
@@ -27,11 +27,11 @@ impl Display for TailwindFontVariantNumeric {
 impl TailwindFontVariantNumeric {
     /// https://tailwindcss.com/docs/font-variant-numeric
     pub fn parse(pattern: &[&str], arbitrary: &TailwindArbitrary) -> Result<Self> {
-        Ok(Self { kind: KeywordOnly::parser("font-numeric", &Self::check_valid)(pattern, arbitrary)? })
+        Ok(Self { kind: StandardValue::parser("font-numeric", &Self::check_valid)(pattern, arbitrary)? })
     }
     /// dispatch to [font-variant-numeric](https://developer.mozilla.org/en-US/docs/Web/CSS/font-variant-numeric)
     pub fn parse_arbitrary(arbitrary: &TailwindArbitrary) -> Result<Self> {
-        Ok(Self { kind: KeywordOnly::parse_arbitrary(arbitrary)? })
+        StandardValue::parse_arbitrary(arbitrary).map(|kind| Self { kind })
     }
     /// https://developer.mozilla.org/en-US/docs/Web/CSS/font-variant-numeric#syntax
     fn check_valid(mode: &str) -> bool {
