@@ -3,17 +3,10 @@ use super::*;
 #[doc=include_str!("readme.md")]
 #[derive(Debug, Clone)]
 pub struct TailwindTextTransform {
-    kind: String,
+    kind: StandardValue,
 }
 
-impl<T> From<T> for TailwindTextTransform
-where
-    T: Into<String>,
-{
-    fn from(kind: T) -> Self {
-        Self { kind: kind.into() }
-    }
-}
+crate::macros::sealed::keyword_instance!(TailwindTextTransform => "text-transform");
 
 impl Display for TailwindTextTransform {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
@@ -21,23 +14,13 @@ impl Display for TailwindTextTransform {
     }
 }
 
-impl TailwindInstance for TailwindTextTransform {
-    fn attributes(&self, _: &TailwindBuilder) -> CssAttributes {
-        css_attributes! {
-            "text-transform" => self.kind
-        }
-    }
-}
-
 impl TailwindTextTransform {
-    /// https://tailwindcss.com/docs/text-transform
+    /// <https://tailwindcss.com/docs/text-transform>
     pub fn parse(pattern: &[&str], arbitrary: &TailwindArbitrary) -> Result<Self> {
-        debug_assert!(arbitrary.is_none(), "forbidden arbitrary after text-transform");
-        let kind = pattern.join("-");
-        debug_assert!(Self::check_valid(&kind));
+        let kind = StandardValue::parser("text-transform", &Self::check_valid)(pattern, arbitrary)?;
         Ok(Self { kind })
     }
-    /// https://developer.mozilla.org/en-US/docs/Web/CSS/text-transform#syntax
+    /// <https://developer.mozilla.org/en-US/docs/Web/CSS/text-transform#syntax>
     pub fn check_valid(mode: &str) -> bool {
         let set = BTreeSet::from_iter(vec![
             "none",
