@@ -1,5 +1,3 @@
-use std::collections::btree_map::Iter;
-
 use super::*;
 
 mod traits;
@@ -11,6 +9,8 @@ mod traits;
 pub struct CssAttributes {
     normal: BTreeMap<String, String>,
     transforms: BTreeSet<String>,
+    backdrop_filter: BTreeSet<String>,
+    filter: BTreeSet<String>,
 }
 
 impl CssAttributes {
@@ -20,54 +20,32 @@ impl CssAttributes {
     /// * `value`: css property
     ///
     /// returns: [`CssAttribute`]
+    #[track_caller]
     pub fn insert<K, V>(&mut self, key: K, value: V)
     where
         K: Into<String>,
         V: Into<String>,
     {
-        self.normal.insert(key.into(), value.into());
+        let key = key.into();
+        match key.as_str() {
+            "transform" => self.transforms.insert(value.into()),
+            "backdrop-filter" => self.backdrop_filter.insert(value.into()),
+            "filter" => self.filter.insert(value.into()),
+            _ => self.normal.insert(key, value.into()).is_some(),
+        };
     }
 
-    ///
-    ///
     /// # Arguments
     ///
     /// * `items`:
     ///
     /// returns: ()
-    ///
-    /// # Examples
-    ///
-    /// ```
-    ///
-    /// ```
     pub fn extend<T>(&mut self, items: T)
     where
         T: IntoIterator<Item = (String, String)>,
     {
-        self.normal.extend(items)
-    }
-
-    ///
-    ///
-    /// # Arguments
-    ///
-    /// * `value`:
-    ///
-    /// returns: ()
-    ///
-    /// # Examples
-    ///
-    /// ```
-    ///
-    /// ```
-    pub fn transform<V>(&mut self, value: V)
-    where
-        V: Into<String>,
-    {
-        self.transforms.insert(value.into());
-    }
-    pub fn iter(&self) -> Iter<'_, String, String> {
-        self.normal.iter()
+        for i in items {
+            self.insert(i.0, i.1);
+        }
     }
 }
