@@ -16,21 +16,12 @@ impl TailwindInstruction {
             ["break", rest @ ..] => TailwindBreak::parse(rest, arbitrary)?,
             ["box", rest @ ..] => Self::box_adaptor(rest, arbitrary)?,
             // begin https://tailwindcss.com/docs/display
+            // skip [flex, table]
             ["block"] => TailwindDisplay::from("block").boxed(),
             ["inline", "block"] => TailwindDisplay::from("inline-block").boxed(),
             ["inline"] => TailwindDisplay::from("inline").boxed(),
-            ["flex"] => TailwindDisplay::from("flex").boxed(),
             ["inline", "flex"] => TailwindDisplay::from("inline-flex").boxed(),
-            ["table"] => TailwindDisplay::from("table").boxed(),
             ["inline", "table"] => TailwindDisplay::from("inline-table").boxed(),
-            ["table", "caption"] => TailwindDisplay::from("table-caption").boxed(),
-            ["table", "cell"] => TailwindDisplay::from("table-cell").boxed(),
-            ["table", "column"] => TailwindDisplay::from("table-column").boxed(),
-            ["table", "column", "group"] => TailwindDisplay::from("table-column-group").boxed(),
-            ["table", "footer", "group"] => TailwindDisplay::from("table-footer-group").boxed(),
-            ["table", "header", "group"] => TailwindDisplay::from("table-header-group").boxed(),
-            ["table", "row", "group"] => TailwindDisplay::from("table-row-group").boxed(),
-            ["table", "row"] => TailwindDisplay::from("table-row").boxed(),
             ["flow", "root"] => TailwindDisplay::from("flow-root").boxed(),
             ["grid"] => TailwindDisplay::from("grid").boxed(),
             ["inline", "grid"] => TailwindDisplay::from("inline-grid").boxed(),
@@ -42,11 +33,12 @@ impl TailwindInstruction {
             ["clear", rest @ ..] => TailwindClear::parse(rest, arbitrary)?.boxed(),
             ["isolate"] => TailwindIsolation::from("isolate").boxed(),
             ["isolation", rest @ ..] => TailwindIsolation::parse(rest, arbitrary)?.boxed(),
-            ["object", rest @ ..] => Self::object_adaptor(rest, arbitrary)?,
-            ["overflow", rest @ ..] => Self::overflow_adaptor(rest, arbitrary)?,
-            ["overscroll", rest @ ..] => Self::overscroll_adaptor(rest, arbitrary)?,
+            ["object", rest @ ..] => object_adaptor(rest, arbitrary)?,
+            ["overflow", rest @ ..] => TailwindOverflow::parse(rest, arbitrary)?.boxed(),
+            ["overscroll", rest @ ..] => TailwindOverscroll::parse(rest, arbitrary)?.boxed(),
             // https://tailwindcss.com/docs/position#header
             [s @ ("static" | "fixed" | "absolute" | "relative" | "sticky")] => TailwindPosition::from(*s).boxed(),
+            ["position", rest @ ..] => TailwindPosition::parse(rest, arbitrary)?.boxed(),
             // https://tailwindcss.com/docs/top-right-bottom-left
             ["inset", rest @ ..] => TailwindInset::parse(rest, arbitrary, neg)?.boxed(),
             ["top", rest @ ..] => TailwindTop::parse(rest, arbitrary, neg)?.boxed(),
@@ -54,8 +46,8 @@ impl TailwindInstruction {
             ["bottom", rest @ ..] => TailwindBottom::parse(rest, arbitrary, neg)?.boxed(),
             ["left", rest @ ..] => TailwindLeft::parse(rest, arbitrary, neg)?.boxed(),
             // https://tailwindcss.com/docs/visibility
-            ["visible"] => TailwindVisibility::from("visible").boxed(),
             ["invisible"] => TailwindVisibility::from("hidden").boxed(),
+            ["visible" | "visibility", rest @ ..] => TailwindVisibility::parse(rest, arbitrary)?.boxed(),
             // https://tailwindcss.com/docs/z-index
             ["z", rest @ ..] => TailwindZIndex::parse(rest, arbitrary, neg)?.boxed(),
             // Flexbox & Grid
@@ -70,7 +62,7 @@ impl TailwindInstruction {
             ["row", rest @ ..] => TailwindRow::parse(rest, arbitrary)?.boxed(),
             ["auto", rest @ ..] => TailwindGridAuto::parse(rest, arbitrary)?.boxed(),
             ["gap", rest @ ..] => TailwindGap::parse(rest, arbitrary)?.boxed(),
-            ["justify", rest @ ..] => Self::justify_adaptor(rest, arbitrary)?,
+            ["justify", rest @ ..] => justify_adaptor(rest, arbitrary)?,
             ["content", rest @ ..] => TailwindContent::adapt(rest, arbitrary)?,
             ["items", rest @ ..] => TailwindItems::parse(rest, arbitrary)?.boxed(),
             ["self", rest @ ..] => TailwindSelf::parse(rest, arbitrary)?.boxed(),
@@ -108,14 +100,14 @@ impl TailwindInstruction {
             // https://tailwindcss.com/docs/letter-spacing
             ["tracking", rest @ ..] => TailwindTracking::parse(rest, arbitrary)?.boxed(),
             ["leading", rest @ ..] => TailwindLeading::parse(rest, arbitrary)?.boxed(),
-            ["list", rest @ ..] => TailwindList::parse(rest, arbitrary)?,
+            ["list", rest @ ..] => list_adaptor(rest, arbitrary)?,
             // https://tailwindcss.com/docs/text-decoration
             ["underline"] => TailwindDecorationLine::from("underline").boxed(),
             ["overline"] => TailwindDecorationLine::from("overline").boxed(),
             ["line", "through"] => TailwindDecorationLine::from("line-through").boxed(),
             ["no", "underline"] => TailwindDecorationLine::from("none").boxed(),
             // https://tailwindcss.com/docs/text-decoration-color
-            ["decoration", rest @ ..] => TailwindDecoration::parse(rest, arbitrary)?,
+            ["decoration", rest @ ..] => TailwindDecoration::adapt(rest, arbitrary)?,
             ["underline", "offset", rest @ ..] => TailwindUnderlineOffset::parse(rest, arbitrary)?.boxed(),
             // https://tailwindcss.com/docs/text-transform
             ["uppercase"] => TailwindTextTransform::from("uppercase").boxed(),
@@ -138,9 +130,9 @@ impl TailwindInstruction {
             ["to", rest @ ..] => TailwindTo::parse(rest, arbitrary)?.boxed(),
             // Borders System
             ["rounded", rest @ ..] => TailwindRounded::parse(rest, arbitrary)?.boxed(),
-            ["border", rest @ ..] => TailwindBorder::adapt(rest, arbitrary)?,
+            ["border", rest @ ..] => Self::border_adaptor(rest, arbitrary)?,
             ["divide", rest @ ..] => TailwindDivide::adapt(rest, arbitrary)?,
-            ["outline", rest @ ..] => TailwindOutline::adapt(rest, arbitrary)?,
+            ["outline", rest @ ..] => outline_adaptor(rest, arbitrary)?,
             ["ring", rest @ ..] => TailwindRing::adapt(rest, arbitrary)?,
             // Effects System
             ["shadow", rest @ ..] => Self::shadow_adaptor(rest, arbitrary)?,
@@ -152,11 +144,11 @@ impl TailwindInstruction {
             ["contrast", rest @ ..] => TailwindContrast::parse(rest, arbitrary, false)?.boxed(),
             ["drop", "shadow", rest @ ..] => TailwindShadow::parse(rest, arbitrary, true)?.boxed(),
             ["grayscale", rest @ ..] => TailwindGrayscale::parse(rest, arbitrary, false)?.boxed(),
-            ["hue", "rotate", rest @ ..] => TailwindHueRotate::parse(rest, arbitrary, false)?.boxed(),
+            ["hue", "rotate", rest @ ..] => TailwindHueRotate::parse(rest, arbitrary, false, neg)?.boxed(),
             ["invert", rest @ ..] => TailwindInvert::parse(rest, arbitrary, false)?.boxed(),
             ["saturate", rest @ ..] => TailwindSaturate::parse(rest, arbitrary, false)?.boxed(),
             ["sepia", rest @ ..] => TailwindSepia::parse(rest, arbitrary, false)?.boxed(),
-            ["backdrop", rest @ ..] => Self::backdrop_adaptor(rest, arbitrary)?,
+            ["backdrop", rest @ ..] => Self::backdrop_adaptor(rest, arbitrary, neg)?,
             // Tables System
             ["table", rest @ ..] => Self::table_adaptor(rest, arbitrary)?,
             // Transitions System
@@ -179,8 +171,8 @@ impl TailwindInstruction {
             ["caret", rest @ ..] => TailwindCaretColor::parse(rest, arbitrary)?.boxed(),
             ["pointer", "events", rest @ ..] => TailwindPointerEvents::parse(rest, arbitrary)?.boxed(),
             ["resize", rest @ ..] => TailwindResize::parse(rest, arbitrary)?.boxed(),
-            ["scroll", rest @ ..] => TailwindScroll::parse(rest, arbitrary, neg)?,
-            ["snap", rest @ ..] => TailwindSnap::adapt(rest, arbitrary)?,
+            ["scroll", rest @ ..] => scroll_adaptor(rest, arbitrary, neg)?,
+            ["snap", rest @ ..] => snap_adaptor(rest, arbitrary)?,
             ["touch", rest @ ..] => TailwindTorch::parse(rest, arbitrary)?.boxed(),
             ["select", rest @ ..] => TailwindSelect::parse(rest, arbitrary)?.boxed(),
             ["will", "change", rest @ ..] => TailwindWillChange::parse(rest, arbitrary)?.boxed(),
@@ -191,7 +183,7 @@ impl TailwindInstruction {
             ["sr", "only"] => TailwindScreenReader::new(true).boxed(),
             ["not", "sr", "only"] => TailwindScreenReader::new(false).boxed(),
             // Form System Extension
-            _ => return syntax_error!("Unknown instructions: {} + [{}]", element.join("-"), arbitrary),
+            _ => return syntax_error!("Unknown instructions: {} + {}", element.join("-"), arbitrary.get_class()),
         };
         Ok(instance)
     }
@@ -202,19 +194,15 @@ impl TailwindInstruction {
             [s @ ("fixed" | "local" | "scroll")] => TailwindBackgroundAttachment::from(*s).boxed(),
             ["attach", rest @ ..] => TailwindBackgroundAttachment::parse(rest, arbitrary)?.boxed(),
             // https://tailwindcss.com/docs/background-clip
-            ["clip", "border"] => TailwindBackgroundClip::from("border-box").boxed(),
-            ["clip", "padding"] => TailwindBackgroundClip::from("padding-box").boxed(),
-            ["clip", "content"] => TailwindBackgroundClip::from("content-box").boxed(),
-            ["clip", "text"] => TailwindBackgroundClip::from("text").boxed(),
+            ["clip", rest @ ..] => TailwindBackgroundClip::parse(rest, arbitrary)?.boxed(),
             // https://tailwindcss.com/docs/background-origin
             ["origin", rest @ ..] => TailwindBackgroundOrigin::parse(rest, arbitrary)?.boxed(),
             // https://tailwindcss.com/docs/background-repeat
-            ["no", "repeat"] => TailwindBackgroundRepeat::from("repeat").boxed(),
+            ["no", "repeat"] => TailwindBackgroundRepeat::from("no-repeat").boxed(),
             ["repeat", rest @ ..] => TailwindBackgroundRepeat::parse(rest, arbitrary)?.boxed(),
             // https://tailwindcss.com/docs/background-size
-            ["auto"] => TailwindBackgroundSize::Auto.boxed(),
-            ["cover"] => TailwindBackgroundSize::Cover.boxed(),
-            ["contain"] => TailwindBackgroundSize::Contain.boxed(),
+            [s @ ("auto" | "cover" | "contain")] => TailwindBackgroundSize::from(*s).boxed(),
+            ["size", rest @ ..] => TailwindBackgroundSize::parse(rest, arbitrary)?.boxed(),
             // https://tailwindcss.com/docs/background-blend-mode
             ["blend", rest @ ..] => TailwindBackgroundBlend::parse(rest, arbitrary)?.boxed(),
             _ => return syntax_error!("Unknown bg instructions: {}", str.join("-")),
@@ -222,13 +210,30 @@ impl TailwindInstruction {
         Ok(out)
     }
     #[inline]
-    fn shadow_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
-        let out = match str {
+    fn border_adaptor(pattern: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
+        let color = |color| TailwindBorderColor::from(color).boxed();
+        let out = match pattern {
+            // https://tailwindcss.com/docs/border-style
+            [s @ ("solid" | "dashed" | "dotted" | "double" | "hidden" | "none")] => TailwindBorderStyle::from(*s).boxed(),
+            // https://tailwindcss.com/docs/border-collapse
+            ["separate"] => TailwindBorderCollapse::from("separate").boxed(),
+            ["collapse"] if arbitrary.is_none() => TailwindBorderCollapse::from("collapse").boxed(),
+            ["collapse", rest @ ..] => TailwindBorderCollapse::parse(rest, arbitrary)?.boxed(),
+            // https://tailwindcss.com/docs/border-color
+            ["black"] => color(TailwindColor::Black),
+            ["white"] => color(TailwindColor::White),
+            _ => return syntax_error!("Unknown border instructions: {}", pattern.join("-")),
+        };
+        Ok(out)
+    }
+    #[inline]
+    fn shadow_adaptor(pattern: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
+        let out = match pattern {
             // https://tailwindcss.com/docs/box-shadow
-            [] => todo!(),
-            ["sm"] => todo!(),
+            ["black" | "white" | "current" | "transparent"] => TailwindShadowColor::parse(pattern, arbitrary)?.boxed(),
+            ["color", rest @ ..] => TailwindShadowColor::parse(rest, arbitrary)?.boxed(),
             // https://tailwindcss.com/docs/box-shadow-color
-            _ => TailwindShadow::parse(str, arbitrary, false)?.boxed(),
+            _ => TailwindShadow::parse(pattern, arbitrary, false)?.boxed(),
         };
         Ok(out)
     }
@@ -236,32 +241,20 @@ impl TailwindInstruction {
     fn box_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
             // https://tailwindcss.com/docs/box-decoration-break
-            ["decoration", rest @ ..] => TailwindBoxDecoration::parse(rest, arbitrary)?.boxed(),
-
+            ["decoration" | "break", rest @ ..] => TailwindBoxDecoration::parse(rest, arbitrary)?.boxed(),
+            ["clone"] => TailwindBoxDecoration::from("clone").boxed(),
+            ["slice"] => TailwindBoxDecoration::from("slice").boxed(),
+            // https://tailwindcss.com/docs/box-sizing
             ["border"] => TailwindBoxSizing::from("border-box").boxed(),
             ["content"] => TailwindBoxSizing::from("content-box").boxed(),
+            ["sizing", rest @ ..] => TailwindBoxSizing::parse(rest, arbitrary)?.boxed(),
             _ => return syntax_error!("Unknown box instructions: {}", str.join("-")),
         };
         Ok(out)
     }
 
     #[inline]
-    fn justify_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
-        debug_assert!(arbitrary.is_none(), "forbidden arbitrary after justify");
-        let out = match str {
-            // https://tailwindcss.com/docs/justify-items
-            ["items", rest @ ..] => TailwindJustifyItems::parse(rest, arbitrary)?.boxed(),
-            // https://tailwindcss.com/docs/justify-self
-            ["self", rest @ ..] => TailwindJustifySelf::parse(rest, arbitrary)?.boxed(),
-            // https://tailwindcss.com/docs/justify-content
-            _ => TailwindJustifyContent::parse(str, arbitrary)?.boxed(),
-        };
-        Ok(out)
-    }
-
-    #[inline]
-    fn backdrop_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
-        debug_assert!(arbitrary.is_none(), "forbidden arbitrary after justify");
+    fn backdrop_adaptor(str: &[&str], arbitrary: &TailwindArbitrary, negative: Negative) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
             // https://tailwindcss.com/docs/backdrop-blur
             ["blur", rest @ ..] => TailwindBlur::parse(rest, arbitrary, true)?.boxed(),
@@ -272,7 +265,7 @@ impl TailwindInstruction {
             // https://tailwindcss.com/docs/backdrop-grayscale
             ["grayscale", rest @ ..] => TailwindGrayscale::parse(rest, arbitrary, true)?.boxed(),
             // https://tailwindcss.com/docs/backdrop-hue-rotate
-            ["hue", "rotate", rest @ ..] => TailwindHueRotate::parse(rest, arbitrary, true)?.boxed(),
+            ["hue", "rotate", rest @ ..] => TailwindHueRotate::parse(rest, arbitrary, true, negative)?.boxed(),
             // https://tailwindcss.com/docs/backdrop-invert
             ["invert", rest @ ..] => TailwindInvert::parse(rest, arbitrary, true)?.boxed(),
             // https://tailwindcss.com/docs/backdrop-opacity
@@ -286,44 +279,20 @@ impl TailwindInstruction {
         Ok(out)
     }
     #[inline]
-    fn table_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
-        let out = match str {
-            // https://tailwindcss.com/docs/display#flex
-            // This won't happen
-            [] => TailwindDisplay::from("table").boxed(),
-            // https://tailwindcss.com/docs/table-layout
-            _ => TailwindTableLayout::parse(str, arbitrary)?.boxed(),
-        };
-        Ok(out)
-    }
-    #[inline]
-    fn object_adaptor(pattern: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
+    fn table_adaptor(pattern: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
         let out = match pattern {
-            // https://tailwindcss.com/docs/object-fit
-            [s @ ("contain" | "cover" | "fill" | "none")] => TailwindObjectFit::from(*s).boxed(),
-            ["scale", "down"] => TailwindObjectFit::from("scale-down").boxed(),
-            // https://tailwindcss.com/docs/object-position
-            _ => TailwindObjectPosition::parse(pattern, arbitrary)?.boxed(),
-        };
-        Ok(out)
-    }
-    #[inline]
-    fn overflow_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
-        let out = match str {
-            // https://tailwindcss.com/docs/overflow
-            ["x", pattern @ ..] => TailwindOverflow::parse(pattern, arbitrary, Some(true))?.boxed(),
-            ["y", pattern @ ..] => TailwindOverflow::parse(pattern, arbitrary, Some(false))?.boxed(),
-            _ => TailwindOverflow::parse(str, arbitrary, None)?.boxed(),
-        };
-        Ok(out)
-    }
-    #[inline]
-    fn overscroll_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
-        let out = match str {
-            // https://tailwindcss.com/docs/overscroll-behavior
-            ["x", pattern @ ..] => TailwindOverscroll::parse(pattern, arbitrary, Some(true))?.boxed(),
-            ["y", pattern @ ..] => TailwindOverscroll::parse(pattern, arbitrary, Some(true))?.boxed(),
-            _ => TailwindOverscroll::parse(str, arbitrary, None)?.boxed(),
+            // https://tailwindcss.com/docs/display#flex
+            [] if arbitrary.is_none() => TailwindDisplay::from("table").boxed(),
+            ["caption"] => TailwindDisplay::from("table-caption").boxed(),
+            ["cell"] => TailwindDisplay::from("table-cell").boxed(),
+            ["column"] => TailwindDisplay::from("table-column").boxed(),
+            ["column", "group"] => TailwindDisplay::from("table-column-group").boxed(),
+            ["footer", "group"] => TailwindDisplay::from("table-footer-group").boxed(),
+            ["header", "group"] => TailwindDisplay::from("table-header-group").boxed(),
+            ["row", "group"] => TailwindDisplay::from("table-row-group").boxed(),
+            ["row"] => TailwindDisplay::from("table-row").boxed(),
+            // https://tailwindcss.com/docs/table-layout
+            _ => TailwindTableLayout::parse(pattern, arbitrary)?.boxed(),
         };
         Ok(out)
     }
