@@ -5,12 +5,11 @@ use tailwind_error::TailwindError;
 
 use tailwind_ast::parse_f32;
 
-use crate::{syntax_error, CssAttributes, CssBehavior, Result, TailwindArbitrary};
-
 pub use self::{
-    anchor::AnchorPoint, axis::SpacingAxis, axis_xy::AxisXY, integer_only::IntegerOnly, keyword_only::KeywordOnly,
-    length::LengthUnit, negative::Negative,
+    anchor::AnchorPoint, axis::SpacingAxis, axis_xy::AxisXY, integer_only::NumericValue, keyword_only::StandardValue,
+    length::LengthUnit, length_only::UnitValue, negative::Negative,
 };
+use crate::{syntax_error, CssAttributes, Result, TailwindArbitrary};
 
 mod anchor;
 mod axis;
@@ -18,4 +17,5 @@ mod axis_xy;
 mod integer_only;
 mod keyword_only;
 mod length;
+mod length_only;
 mod negative;
